All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] drm/i915: Use AUX for backlight only if eDP 1.4 or later
@ 2017-07-19 10:29 Jenny TC
  2017-07-19 11:50 ` ✓ Fi.CI.BAT: success for " Patchwork
  2017-07-19 18:22 ` [PATCH] " Pandiyan, Dhinakaran
  0 siblings, 2 replies; 15+ messages in thread
From: Jenny TC @ 2017-07-19 10:29 UTC (permalink / raw)
  To: intel-gfx
  Cc: Puthikorn Voravootivat, Daniel Vetter, Jenny TC, David Weinehall

With older panels, AUX pin for backlight doesn't work. On some
panels, this causes backlight issues on S3 resume. Enable the
feature only for eDP1.4 or later.

Fix-suggested-by: Puthikorn Voravootivat <puthik@chromium.org>
Signed-off-by: Jenny TC <jenny.tc@intel.com>
---
 drivers/gpu/drm/i915/intel_dp_aux_backlight.c | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/drivers/gpu/drm/i915/intel_dp_aux_backlight.c b/drivers/gpu/drm/i915/intel_dp_aux_backlight.c
index b25cd88..421f31f 100644
--- a/drivers/gpu/drm/i915/intel_dp_aux_backlight.c
+++ b/drivers/gpu/drm/i915/intel_dp_aux_backlight.c
@@ -292,7 +292,7 @@ static int intel_dp_aux_setup_backlight(struct intel_connector *connector,
  * via PWM pin or using AUX is better than using PWM pin.
  *
  * The heuristic to determine that using AUX pin is better than using PWM pin is
  * that the panel support any of the feature list here.
  * - Regional backlight brightness adjustment
  * - Backlight PWM frequency set
  * - More than 8 bits resolution of brightness level
@@ -310,6 +310,10 @@ static int intel_dp_aux_setup_backlight(struct intel_connector *connector,
 	if (!(intel_dp->edp_dpcd[2] & DP_EDP_BACKLIGHT_BRIGHTNESS_PWM_PIN_CAP))
 		return true;
 
+	/* Enable this for eDP 1.4 panel or later. */
+	if (intel_dp->edp_dpcd[0] < DP_EDP_14)
+		return false;
+
 	/* Panel supports regional backlight brightness adjustment */
 	if (drm_dp_dpcd_readb(&intel_dp->aux, DP_EDP_GENERAL_CAP_3,
 			      &reg_val) != 1) {
@@ -292,7 +292,7 @@ static int intel_dp_aux_setup_backlight(struct intel_connector *connector,
  *
  * The heuristic to determine that using AUX pin is better than using PWM pin is
- * that the panel support any of the feature list here.
+ * that the panel is eDP 1.4 or later and support any of the feature list here
  * - Regional backlight brightness adjustment
  * - Backlight PWM frequency set
-- 
1.9.1

_______________________________________________
Intel-gfx mailing list
Intel-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/intel-gfx

^ permalink raw reply related	[flat|nested] 15+ messages in thread

end of thread, other threads:[~2017-08-02 13:53 UTC | newest]

Thread overview: 15+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2017-07-19 10:29 [PATCH] drm/i915: Use AUX for backlight only if eDP 1.4 or later Jenny TC
2017-07-19 11:50 ` ✓ Fi.CI.BAT: success for " Patchwork
2017-07-19 18:22 ` [PATCH] " Pandiyan, Dhinakaran
2017-07-20  9:33   ` Jani Nikula
2017-07-20 10:06     ` Tc, Jenny
2017-07-20 20:27       ` Pandiyan, Dhinakaran
2017-07-24 23:15         ` Puthikorn Voravootivat
2017-07-25 12:41           ` David Weinehall
2017-07-25 13:11             ` David Weinehall
2017-07-31 10:55           ` Jani Nikula
2017-07-31 22:41             ` Puthikorn Voravootivat
2017-08-01 23:15               ` Pandiyan, Dhinakaran
2017-08-02 13:53                 ` David Weinehall
2017-07-20 15:35     ` David Weinehall
2017-07-20 18:20       ` Pandiyan, Dhinakaran

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.